# frozen_string_literal: true

module Formulas
  autoload :StudentLoanRepayment, 'formulas/student_loan_repayment'
  autoload :Salary, 'formulas/salary'
  autoload :PAYE, 'formulas/paye'
  autoload :PAYG, 'formulas/payg'
  autoload :Income, 'formulas/income'
  autoload :WithholdingTax, 'formulas/withholding_tax'
  autoload :Superannuation, 'formulas/superannuation'
  autoload :LoanPrincipalCalculator, 'formulas/loan_principal_calculator'

  MULTIPLIER_IN_FREQUENCY = {
    weekly: 52,
    fortnightly: 26,
    four_weeks: 13,
    monthly: 12
  }

  ANNUALLY = :annually
  WEEKLY = :weekly
  FORTNIGHTLY = :fortnightly
  MONTHLY = :monthly

  FREQUENCIES = [ANNUALLY, WEEKLY, FORTNIGHTLY, MONTHLY]

  module FrequencyConversions
    def convert_annually_to_annually(number)
      number
    end
    alias :convert_weekly_to_weekly convert_annually_to_annually
    alias :convert_fortnightly_to_fortnightly convert_annually_to_annually
    alias :convert_monthly_to_monthly convert_annually_to_annually

    def convert_annually_to_weekly(number)
      number.to_f / 52
    end

    def convert_annually_to_monthly(number)
      number.to_f / 12
    end

    def convert_annually_to_fortnightly(number)
      number.to_f / 26
    end

    def convert_weekly_to_annually(number)
      number.to_f * 52
    end

    def convert_weekly_to_monthly(number)
      number.to_f * 52 / 12
    end

    def convert_weekly_to_fortnightly(number)
      number.to_f * 52 / 26
    end

    def convert_monthly_to_annually(number)
      number.to_f * 12
    end

    def convert_monthly_to_weekly(number)
      number.to_f * 12 / 52
    end

    def convert_monthly_to_fortnightly(number)
      number.to_f * 12 / 26
    end

    def convert_fortnightly_to_annually(number)
      number.to_f * 26
    end

    def convert_fortnightly_to_weekly(number)
      number.to_f / 2
    end

    def convert_fortnightly_to_monthly(number)
      (number.to_f * 26) / 12
    end
  end
end