# frozen_string_literal: true
# https://www.ato.gov.au/Rates/Individual-income-tax-rates/
#
module Formulas
  # Calculate basic salary in frequency
  # paye = Formulas::PAYE.new(gross_pay: 52_000, frequency: Formulas::ANNUAL)
  #
  # paye.tax(:monthly)
  # => 718.33
  #
  # Provide a way to calculate pay as you earn calculator
  class PAYE < WithholdingTax
    # Provide a way to calculate PAYE tax
    TAX_RATES = [
      [[0, 14_000], 10.5],
      [[14_000, 48_000], 17.5],
      [[48_000, 70_000], 30],
      [[70_000, 180_000], 33],
      [[180_000], 39]
    ]

    MAX_ACC_LEVY_PAYABLE = 130_911

    def initialize(gross_pay:, frequency: Formulas::MONTHLY)
      super(gross_pay, frequency, TAX_RATES)
    end

    def tax(request_frequency: Formulas::WEEKLY)
      calculate_tax(request_frequency)
    end

    def levy
      0.0139
    end

    def acc_payable
      annual_gross_pay > MAX_ACC_LEVY_PAYABLE ? MAX_ACC_LEVY_PAYABLE : annual_gross_pay
    end
  end
end