# frozen_string_literal: true

module Formulas
  # Calculate basic salary in frequency
  # salary = Formulas::Salary.new(pay: 52_000, Salary::ANNUAL)
  #
  # salary.pay(:monthly)
  #
  # Provide a way to calculate salary in different frequencies
  # It provide summaries of salary breakdown after deductions
  # such as withholding tax, super, health care and methods to
  # get the take home pay
  #
  class Salary
    include FrequencyConversions
    attr_reader :frequency

    def initialize(pay:, frequency:)
      @pay = pay
      @frequency = frequency.to_sym

      invalid_frequency unless FREQUENCIES.include?(@frequency)
      raise ArgumentError, 'Gross pay must be numeric' unless Numeric === pay
    end

    def pay(request_frequency: @frequency)
      invalid_frequency unless FREQUENCIES.include?(frequency)
      return @pay if @frequency == request_frequency

      convert_pay_to(request_frequency).round(2)
    end

    private

    def invalid_frequency
      raise ArgumentError, "Invalid frequency, frequency are: #{FREQUENCIES.join(', ')}"
    end

    def convert_pay_to(request_frequency)
      send("convert_#{@frequency}_to_#{request_frequency}", @pay)
    end
  end
end
