# frozen_string_literal: true

# require_relative 'student_loan_repayment/fix_repayment_per_period'

module Formulas

  # Provide calculation to work out student loan repayment in frequency
  # loan = StudentLoan.new(salary_amount: 1000, salary_frequency: Income::Salary::WEEKLY)
  #
  # loan.repayment
  # => <#ConstantPerPeriod>
  #
  # loan.repayment
  # => 317
  #
  #
  module StudentLoanRepayment
    autoload :RepaymentBase, 'formulas/student_loan_repayment/repayment_base'
    autoload :FixRepaymentPerPeriod, 'formulas/student_loan_repayment/fix_repayment_per_period'
    autoload :PercentRepaymentPerThreshold, 'formulas/student_loan_repayment/percent_repayment_per_threshold'
    attr_reader :repayment

    def initialize(income_strategy: , repayment_strategy:, rates:)
      raise 'Missing required salary' unless income_strategy
      raise 'Missing required repayment rates' unless rates
      raise 'Missing required repayment strategy' unless repayment_strategy

      @repayment = repayment_strategy.new(salary: income_strategy, repayment: rates)
    end
  end
end