# frozen_string_literal: true
#
# @salary = Formulas::Salary.new(gross_pay: 100_000, frequency: Formulas::ANNUALLY)
# @repayment_rates = Formulas::StudentLoanRepayment::FixRepaymentPerPeriod::DEFAULT_THRESHOLD
#
# loan = Formulas::StudentLoanRepayment::FixRepaymentPerPeriod.new(salary: @salary, repayment: @repayment_rates)
# assert_equal loan.repayment, 797.2
#
module Formulas
  module StudentLoanRepayment
    class FixRepaymentPerPeriod < RepaymentBase
      FIX_RATE = 0.12

      DEFAULT_THRESHOLD = {
        weekly: [390, 52],
        fortnightly: [780, 26],
        four_weeks: [1560, 13],
        monthly: [1690, 12],
        annually: [20280, 1],
      }

      def repayment
        selected_base = @repayment_threshold[@salary.frequency]
        less_base_cost = @salary.pay - selected_base[0]
        ((FIX_RATE * less_base_cost * selected_base[1]) / 12).round(2)
      end
    end
  end
end
