# frozen_string_literal: true

module Formulas
  # Calculate the super using the as per frequency
  #
  # salary = Formulas::Salary.new(gross_pay: 52_000, Salary::ANNUAL)
  # super = Super.new(salary: salary, Super::KIWISAVER)
  #
  # super.calculate
  # => 1,560.00
  #
  # super.calculate(Formulas::WEEKLY)
  # => 30.00
  #
  class Superannuation
    include FrequencyConversions

    KIWISAVER = 3
    AU_SUPER = 10

    def initialize(salary:, superannuation:)
      @salary =  salary
      @super = superannuation
    end

    def calculate(request_frequency: Formulas::ANNUALLY)
      result = @salary.pay(request_frequency: request_frequency) * (@super.to_f / 100)
      result.round(2)
    end
  end
end