# frozen_string_literal: true

module Formulas
  class WithholdingTax
    include FrequencyConversions

    attr_reader :origin_frequency

    def initialize(gross_pay, origin_frequency, tax_rate, options: {})
      @gross_pay = gross_pay
      @origin_frequency = origin_frequency
      @tax_rate = tax_rate
      @options = options
    end

    def net_pay(request_frequency:)
      annual_pay_after_tax = annual_gross_pay - calculate_tax(Formulas::ANNUALLY)

      if respond_to?(:levy)
        net_pay = annual_pay_after_tax - (acc_payable * send(:levy))
      end

      return net_pay if request_frequency.to_s == Formulas::ANNUALLY.to_s

      send("convert_annually_to_#{request_frequency}", net_pay).round(2)
    end

    protected

    def calculate_tax(request_frequency)
      @request_frequency = request_frequency

      return annual_tax if request_frequency.to_s == Formulas::ANNUALLY.to_s

      send("convert_annually_to_#{request_frequency}", annual_tax).round(2)
    end

    private

    def annual_tax
      annual_result = 0

      if gross_pay_tax_index > 0
        @tax_rate[0..gross_pay_tax_index].each_with_index do |current, index|
          l = (index == gross_pay_tax_index) ? annual_gross_pay : current[0][1]
          annual_result += ((l - current[0][0]) * (current[1].to_f / 100))
        end
      end
      annual_result
    end

    def annual_gross_pay
      return @gross_pay if @origin_frequency.to_s == Formulas::ANNUALLY.to_s
      send("convert_#{@origin_frequency}_to_annually", @gross_pay)
    end

    def gross_pay_tax_index
      @tax_rate.index do |current|
        (current[0][0] <= annual_gross_pay && current[0][1].nil?) ||
          (current[0][0] <= annual_gross_pay && current[0][1] >= annual_gross_pay)
      end
    end
  end
end